from bilby.core.result import read_in_result
import matplotlib.pyplot as plt
import numpy as np

from matplotlib import rcParams

rcParams["text.usetex"] = True
rcParams["font.serif"] = "Time New Roman"
rcParams["font.family"] = "Serif"
rcParams["xtick.labelsize"]=14
rcParams["ytick.labelsize"]=14
rcParams.update({'font.size': 16})
rcParams["legend.fontsize"]=14


colours = ["#08306b","#4d9221","#1f78b4","#08306b","#4d9221","#1f78b4"]
label = ["\\textsc{Truncated}", "\\textsc{Broken Power-law}", "\\textsc{Power-law Peak}", "\\textsc{Truncated} - includes GW190814", "\\textsc{Broken Power-law} - includes GW190814", "\\textsc{Power-law Peak} - includes GW190814"]

filenames = ["../../Population_Samples/default/o1o2o3_mass_b_iid_mag_two_comp_iid_tilt_powerlaw_redshift_result.json",
             "../../Population_Samples/default/o1o2o3_mass_d_iid_mag_two_comp_iid_tilt_powerlaw_redshift_result.json",
             "../../Population_Samples/default/o1o2o3_mass_c_iid_mag_two_comp_iid_tilt_powerlaw_redshift_result.json",
             "../../Population_Samples/all_events/o1o2o3_mass_b_iid_mag_two_comp_iid_tilt_powerlaw_redshift_result.json",
             "../../Population_Samples/all_events/o1o2o3_mass_d_iid_mag_two_comp_iid_tilt_powerlaw_redshift_result.json",
             "../../Population_Samples/all_events/o1o2o3_mass_c_iid_mag_two_comp_iid_tilt_powerlaw_redshift_result.json",
             ]

plt.figure(figsize=(9,6))
i = 0
binwidth = 0.15
for ff in filenames:
    if i < 3:
        linestyle='solid'
        alpha = 0.5
        histtype ='bar'
        rwidth=0.95
    else:
        linestyle='dashed'
        histtype ='step'
        rwidth=0.95
        alpha=1.0
    result = read_in_result(ff)
    post = result.posterior
    mmin = post["mmin"]
    plt.hist(mmin, bins=np.arange(min(mmin), max(mmin) + binwidth, binwidth), label=label[i], density=True, linestyle=linestyle, color=colours[i], linewidth=2,histtype=histtype, alpha=alpha, rwidth=0.95)
    i +=1

plt.tight_layout()
plt.legend()
plt.xlabel("$m_\mathrm{min}$ [$\mathrm{M}_{\\odot}$]")
plt.ylabel("$p(m_\mathrm{min})$")
plt.xlim(2,7)
plt.tight_layout()
plt.savefig("GW190814_mmin_hist_comparison.png")
